@@ -164,7 +164,28 @@ class IndexQueryset(LazyQueryset):
 
         # Geo index
         if index_field.index_type_obj.type_name == 'geo':
-            pass
+
+            if 'radius' in self._filters:
+                result = SimpleIndexQuery.within(
+                    collection=index_field.collection,
+                    index_id=index_field.index_type_obj.id,
+                    latitude=self._filters['latitude'],
+                    longitude=self._filters['longitude'],
+                    radius=self._filters['radius'],
+                    distance=self._filters['distance'],
+                    skip=skip,
+                    limit=limit,
+                )
+            else:
+                result = SimpleIndexQuery.near(
+                    collection=index_field.collection,
+                    index_id=index_field.index_type_obj.id,
+                    latitude=self._filters['latitude'],
+                    longitude=self._filters['longitude'],
+                    distance=self._filters['distance'],
+                    skip=skip,
+                    limit=limit,
+                )
 
         # Save cache
         if isinstance(result, list):
@@ -333,14 +354,23 @@ class CollectionModelManager(object):
 
     def get_or_create(self, **kwargs):
         """
+            Looks up an object with the given kwargs, creating one if necessary.
+            Returns a tuple of (object, created), where created is a boolean
+            specifying whether an object was created.
         """
 
         model = self.get(**kwargs)
 
+        is_created = False
+
         if model is None:
+            is_created = True
             model = self._model_class()
 
-        return model
+            for key, value in kwargs.items():
+                setattr(model, key, value)
+
+        return model, is_created
 
     def all(self):
         """
@@ -404,6 +434,33 @@ class CollectionModelManager(object):
 
         return queryset.filter(**kwargs)
 
+    def search_near(self, index, latitude, longitude, distance=None, **kwargs):
+        """
+        """
+
+        queryset = IndexQueryset(manager=self)
+        queryset.set_index(index=index)
+
+        kwargs['latitude'] = latitude
+        kwargs['longitude'] = longitude
+        kwargs['distance'] = distance
+
+        return queryset.filter(**kwargs)
+
+    def search_within(self, index, latitude, longitude, radius, distance=None, **kwargs):
+        """
+        """
+
+        queryset = IndexQueryset(manager=self)
+        queryset.set_index(index=index)
+
+        kwargs['latitude'] = latitude
+        kwargs['longitude'] = longitude
+        kwargs['radius'] = radius
+        kwargs['distance'] = distance
+
+        return queryset.filter(**kwargs)
+
     def _create_model_from_doc(self, doc, model_class=None):
         """
         """
