@@ -1082,15 +1082,16 @@ class CollectionModelManagerTestCase(unittest.TestCase):
         all_models = TestModel.objects.all()
         self.assertEqual(len(all_models), 0)
 
-        model = TestModel.objects.get_or_create(active=True)
+        model, is_created = TestModel.objects.get_or_create(active=True)
 
-        self.assertEqual(model.active, False)
+        self.assertEqual(is_created, True)
+        self.assertEqual(model.active, True)
 
-        model.active = True
         model.save()
 
-        model = TestModel.objects.get_or_create(active=True)
+        model, is_created = TestModel.objects.get_or_create(active=True)
 
+        self.assertEqual(is_created, False)
         self.assertEqual(model.active, True)
 
         all_models = TestModel.objects.all()
@@ -1381,6 +1382,84 @@ class CollectionModelManagerForIndexTestCase(unittest.TestCase):
 
         TestModel.destroy()
 
+    def test_search_geo_near_index(self):
+
+        class TestModel(CollectionModel):
+
+            position_index = GeoIndex(fields=['latitude', 'longitude'], geo_json=False)
+            latitude = NumberField(required=True, null=False)
+            longitude = NumberField(required=True, null=False)
+
+        TestModel.init()
+
+        # Paris
+        model1 = TestModel()
+        model1.latitude = 48.853333
+        model1.longitude = 2.348611
+        model1.save()
+
+        # Koeln
+        model2 = TestModel()
+        model2.latitude = 50.933333
+        model2.longitude = 6.95
+        model2.save()
+
+        # Brussels
+        models = TestModel.objects.search_near(
+            index='position_index',
+            latitude=50.850278,
+            longitude=4.348611,
+            limit=1,
+        )
+
+        self.assertEqual(len(models), 1)
+
+        model = models[0]
+        self.assertEqual(model.id, model2.id)
+
+        TestModel.destroy()
+
+    def test_search_geo_within_index(self):
+
+        class TestModel(CollectionModel):
+
+            position_index = GeoIndex(fields=['latitude', 'longitude'], geo_json=False)
+            latitude = NumberField(required=True, null=False)
+            longitude = NumberField(required=True, null=False)
+
+        TestModel.init()
+
+        # Paris
+        model1 = TestModel()
+        model1.latitude = 48.853333
+        model1.longitude = 2.348611
+        model1.save()
+
+        # Koeln
+        model2 = TestModel()
+        model2.latitude = 50.933333
+        model2.longitude = 6.95
+        model2.save()
+
+        radius_kilometers = 400
+        radius_meters = radius_kilometers * 1000
+
+        # Brussels
+        models = TestModel.objects.search_within(
+            index='position_index',
+            latitude=50.850278,
+            longitude=4.348611,
+            radius=radius_meters,
+            limit=1,
+        )
+
+        self.assertEqual(len(models), 1)
+
+        model = models[0]
+        self.assertEqual(model.id, model2.id)
+
+        TestModel.destroy()
+
 
 class CollectionModelForeignKeyFieldTestCase(unittest.TestCase):
     def setUp(self):
